summaryrefslogtreecommitdiffstats
path: root/kandy/src/mobilegui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/mobilegui.cpp')
-rw-r--r--kandy/src/mobilegui.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kandy/src/mobilegui.cpp b/kandy/src/mobilegui.cpp
index fec40b7f..08cf54cc 100644
--- a/kandy/src/mobilegui.cpp
+++ b/kandy/src/mobilegui.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <time.h>
@@ -148,7 +148,7 @@ class AddressSyncer
};
-class PhoneBookItem : public QCheckListItem
+class PhoneBookItem : public TQCheckListItem
{
public:
PhoneBookItem( TQListView *v ) :
@@ -176,21 +176,21 @@ class PhoneBookItem : public QCheckListItem
/*
* Constructs a MobileGui which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
MobileGui::MobileGui( CommandScheduler *scheduler, KandyPrefs *kprefs,
- TQWidget* parent, const char* name, WFlags fl ) :
- DCOPObject( "KandyIface" ), MobileGui_base( parent, name, fl )
+ TQWidget* tqparent, const char* name, WFlags fl ) :
+ DCOPObject( "KandyIface" ), MobileGui_base( tqparent, name, fl )
{
// Setup links to related classes
mScheduler = scheduler;
mSyncer = new AddressSyncer;
mPrefs = kprefs;
- mparent = parent;
+ mtqparent = tqparent;
// Setup mobile phone specific data
mMobManufacturer = "";
@@ -922,7 +922,7 @@ void MobileGui::writeKabc()
*fields = TQStringList::split( ',', name );
if ( fields->count() > 1 ) {
// Name string tqcontains comma separated entry so that we
// need to build family and given names out of them.
TQString givenName = "";
@@ -933,7 +933,7 @@ void MobileGui::writeKabc()
givenName += stripWhiteSpaces( (*fields)[ i ] ) + " ";
entry.setGivenName( stripWhiteSpaces( givenName ) );
} else
// Name string tqcontains only one string without comma.
entry.setFamilyName( stripWhiteSpaces( name ) );
entry.insertPhoneNumber( KABC::PhoneNumber( phoneNumber, phoneType ) );
@@ -954,7 +954,7 @@ void MobileGui::writeKabc()
}
-void MobileGui::refreshStatus()
+void MobileGui::refreshtqStatus()
{
mScheduler->executeId( "+cbc" );
mScheduler->executeId( "+csq" );
@@ -1453,7 +1453,7 @@ void MobileGui::toggleConnection()
emit connectModem();
readModelInformation();
- refreshStatus();
+ refreshtqStatus();
mConnectButton->setText( tr2i18n( "Disconnect" ) );
PushButton1->setEnabled( true );
@@ -1463,7 +1463,7 @@ void MobileGui::toggleConnection()
setKabState( UNLOADED );
setMobState( UNLOADED );
- ((MobileMain *) mparent)->statusBar()->changeItem( i18n(" Connected "), 1 );
+ ((MobileMain *) mtqparent)->statusBar()->changeItem( i18n(" Connected "), 1 );
} else {
warnKabState( UNLOADED );
@@ -1510,7 +1510,7 @@ void MobileGui::disconnectGUI()
mPBIndexOccupied.resize( 0, false );
- ((MobileMain *) mparent)->statusBar()->changeItem( i18n(" Disconnected "),
+ ((MobileMain *) mtqparent)->statusBar()->changeItem( i18n(" Disconnected "),
1 );
}
@@ -1561,7 +1561,7 @@ void MobileGui::warnKabState( ABState newState )
{
if ( ( mKabState == MODIFIED ) && ( newState != MODIFIED ) ) {
TQString text = "<qt><b>" + i18n( "Warning" ) + "</b><br>";
- text += i18n( "The KDE address book tqcontains unsaved changes." ) +
+ text += i18n( "The KDE address book contains unsaved changes." ) +
"<br></qt>";
TQMessageBox *msg = new TQMessageBox( i18n( "Unsaved Changes" ), text,
@@ -1646,7 +1646,7 @@ bool MobileGui::warnMobState( ABState newState )
if ( ( mMobState == MODIFIED ) && ( newState != MODIFIED ) )
{
TQString text = "<qt><b>" + i18n( "Warning" ) + "</b><br>";
- text += i18n( "The mobile phone book tqcontains unsaved changes." ) +
+ text += i18n( "The mobile phone book contains unsaved changes." ) +
"<br></qt>";
TQMessageBox *msg = new TQMessageBox( i18n( "Unsaved Changes" ), text,
@@ -176,21 +176,21 @@ class PhoneBookItem : public QCheckListItem
/*
- * Constructs a MobileGui which is a child of 'parent', with the
+ * Constructs a MobileGui which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
@@ -922,7 +922,7 @@ void MobileGui::writeKabc()
*fields = TQStringList::split( ',', name );
if ( fields->count() > 1 ) {
- // Name string tqcontains comma separated entry so that we
+ // Name string contains comma separated entry so that we
// need to build family and given names out of them.
TQString givenName = "";
@@ -933,7 +933,7 @@ void MobileGui::writeKabc()
entry.setGivenName( stripWhiteSpaces( givenName ) );
} else
- // Name string tqcontains only one string without comma.
+ // Name string contains only one string without comma.
entry.setFamilyName( stripWhiteSpaces( name ) );
entry.insertPhoneNumber( KABC::PhoneNumber( phoneNumber, phoneType ) );